@@ -38,7 +38,7 @@ public:
 
     void print(const KContacts::Addressee::List &, PrintProgress *) override;
 private:
-    KAddressBookGrantlee::GrantleePrint *mGrantleePrint = nullptr;
+    QString m_themePath;
 };
 
 class GrantleeStyleFactory : public PrintStyleFactory
